aboutsummaryrefslogtreecommitdiffstats
path: root/host/lib/include/uhdlib/rfnoc
diff options
context:
space:
mode:
Diffstat (limited to 'host/lib/include/uhdlib/rfnoc')
-rw-r--r--host/lib/include/uhdlib/rfnoc/radio_control_impl.hpp17
1 files changed, 10 insertions, 7 deletions
diff --git a/host/lib/include/uhdlib/rfnoc/radio_control_impl.hpp b/host/lib/include/uhdlib/rfnoc/radio_control_impl.hpp
index 5327105c8..fc0d19a0a 100644
--- a/host/lib/include/uhdlib/rfnoc/radio_control_impl.hpp
+++ b/host/lib/include/uhdlib/rfnoc/radio_control_impl.hpp
@@ -241,13 +241,16 @@ public:
struct err_codes
{
- static const uint32_t ERR_RX_LATE_CMD =
- 1; // Late command (arrived after indicated time)
- static const uint32_t ERR_RX_OVERRUN = 2; // FIFO overflow
- static const uint32_t ERR_TX_UNDERRUN =
- 1; // Data underflow (data not available when needed)
- static const uint32_t ERR_TX_LATE_DATA =
- 2; // Late data (arrived after indicated time)
+ //! Late command (stream command arrived after indicated time)
+ static const uint32_t ERR_RX_LATE_CMD = 1;
+ //! FIFO overflow
+ static const uint32_t ERR_RX_OVERRUN = 2;
+ // FIFO underrun (data not available when needed)
+ static const uint32_t ERR_TX_UNDERRUN = 1;
+ //! Late data (arrived after indicated time)
+ static const uint32_t ERR_TX_LATE_DATA = 2;
+ //! Acknowledge a TX burst with an EOB
+ static const uint32_t EVENT_TX_BURST_ACK = 3;
};
//! Tree path to the dboard-specific properties